@@ -1,17 +1,14 @@
 package FusionInventory::Agent::XML::Response::Prolog;
 
 use strict;
-use FusionInventory::Agent::XML::Response;
-
-our @ISA = ('FusionInventory::Agent::XML::Response');
+use warnings;
+use base 'FusionInventory::Agent::XML::Response';
 
 sub new {
     my ($class, @params) = @_;
 
     my $self = $class->SUPER::new(@params);
 
-    bless ($self, $class);
-
     my $target = $self->{target};
 
     my $parsedContent = $self->getParsedContent();
@@ -25,11 +22,16 @@ sub isInventoryAsked {
     my $self = shift;
 
     my $parsedContent = $self->getParsedContent();
-    if ($parsedContent && exists ($parsedContent->{RESPONSE}) && $parsedContent->{RESPONSE} =~ /^SEND$/) {
-	return 1;
-    }
 
-    0
+    if (
+        $parsedContent &&
+        exists $parsedContent->{RESPONSE} &&
+        $parsedContent->{RESPONSE} eq 'SEND'
+    ) {
+        return 1;
+    } else {
+        return 0;
+    }
 }
 
 sub getOptionsInfoByName {
